admin

package
v2.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package admin exposes convenient constructors for the extensible Admin API.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server = api.Server

Server is the Admin API HTTP server.

func New

func New() *Server

New creates an Admin API server without external repositories.

func NewInsecureDevelopmentServer added in v2.0.2

func NewInsecureDevelopmentServer() *Server

NewInsecureDevelopmentServer creates an unauthenticated loopback-only development server.

func NewWithDependencies

func NewWithDependencies(deps api.Dependencies) *Server

func NewWithPlugins

func NewWithPlugins(plugins *plugin.Registry) *Server

func NewWithStore

func NewWithStore(store storage.Store) *Server

NewWithStore creates an Admin API backed by the standard system store.

Directories

Path Synopsis
Package api provides the extensible HTTP Admin API server.
Package api provides the extensible HTTP Admin API server.
Package auth defines Admin API authentication claims and verification.
Package auth defines Admin API authentication claims and verification.
Package control implements Astra Admin Control WebSocket protocol v1.
Package control implements Astra Admin Control WebSocket protocol v1.
Package observability records handler events, audits and basic runtime metrics.
Package observability records handler events, audits and basic runtime metrics.
Package resources defines declarative Admin API resource metadata.
Package resources defines declarative Admin API resource metadata.
Package ui defines the declarative Astra Admin UI protocol.
Package ui defines the declarative Astra Admin UI protocol.

Jump to